cancel method
Immediately aborts the current session with no final result.
Implementation
Future<void> cancel() {
throw UnimplementedError('cancel() has not been implemented.');
}
Immediately aborts the current session with no final result.
Future<void> cancel() {
throw UnimplementedError('cancel() has not been implemented.');
}