events property

Stream<LocalVoiceEvent> get events

Stream of transcript, error, and status events for the lifetime of the plugin. A single broadcast stream is shared across listen sessions.

Implementation

Stream<LocalVoiceEvent> get events {
  throw UnimplementedError('events has not been implemented.');
}